package com.glxp.udidl.admin.service.collect;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.glxp.udidl.admin.dao.collect.ThirdAliDrugMapper;
import com.glxp.udidl.admin.entity.collect.ThirdAliDrug;
import com.glxp.udidl.admin.req.alihealth.AlihealthKytDrugrescodeReqeust;
import com.glxp.udidl.admin.req.alihealth.local.AlihealthThirdAliDrugInsertReqeust;
import com.glxp.udidl.admin.req.collect.ThirdAliDrugAddRequest;
import com.glxp.udidl.admin.req.collect.ThirdAliDrugRequest;
import com.glxp.udidl.admin.res.BaseResponse;
import com.glxp.udidl.admin.util.alihealth.AlihealthUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;


@Service
@Slf4j
public class ThirdAliDrugService extends ServiceImpl<ThirdAliDrugMapper, ThirdAliDrug> {


    public List<ThirdAliDrug> filterList(ThirdAliDrugRequest thirdAliDrug) {
        if (thirdAliDrug == null) {
            return Collections.emptyList();
        }
        if (thirdAliDrug.getPage() != null) {
            int offset = (thirdAliDrug.getPage() - 1) * thirdAliDrug.getLimit();
            PageHelper.offsetPage(offset, thirdAliDrug.getLimit());
        }
        return this.baseMapper.filterList(thirdAliDrug);
    }


    public List<ThirdAliDrug> findByByApproved(String approvalNum) {
        return this.baseMapper.selectList(new LambdaQueryWrapper<ThirdAliDrug>().eq(ThirdAliDrug::getApprovalNum, approvalNum));
    }

    public void addThirdAliDrug(ThirdAliDrugAddRequest relCodeBatchRequest) {
        List<ThirdAliDrug> list = relCodeBatchRequest.getList();
        if (CollUtil.isNotEmpty(list)){
            List<String> nameCodes = list.stream().map(ThirdAliDrug::getNameCode).collect(Collectors.toList());
            List<String> updateNameCodes = new ArrayList<>();
            List<ThirdAliDrug> drugs = this.list(new LambdaQueryWrapper<ThirdAliDrug>().in(ThirdAliDrug::getNameCode, nameCodes));
            if (CollUtil.isNotEmpty(drugs)){
                updateNameCodes = drugs.stream().map(ThirdAliDrug::getNameCode).collect(Collectors.toList());
            }
            List<ThirdAliDrug> addList = new ArrayList<>();
            List<String> finalUpdateNameCodes = updateNameCodes;
            list.forEach(item -> {
                if (finalUpdateNameCodes.size() > 0 ){
                    if (!finalUpdateNameCodes.contains(item.getNameCode())){
                        item.setId(null);
                        addList.add(item);
                    }
                }else {
                    item.setId(null);
                    addList.add(item);
                }
            });

            if (CollUtil.isNotEmpty(addList)){
                this.baseMapper.saveOrUpdateBatch(addList);
            }

        }
    }
    @Resource
    private AlihealthUtils alihealthUtils;

    public void updateThirdAliDrugTask() {
        List<ThirdAliDrug> groupedByCpmctymc = this.baseMapper.groupByCpmctymc();
        if (CollUtil.isNotEmpty(groupedByCpmctymc)){
            for (int i = 0; i < groupedByCpmctymc.size(); i++) {
                ThirdAliDrug thirdAliDrug = groupedByCpmctymc.get(i);
                String cpmctymc = thirdAliDrug.getCpmctymc();

                ThirdAliDrugAddRequest thirdAliDrugAddRequest = new ThirdAliDrugAddRequest();
                // TODO: 2025/1/4 这里用调用的 入参 cpmctymc
                List<ThirdAliDrug> add  = null;
                AlihealthThirdAliDrugInsertReqeust request  = new AlihealthThirdAliDrugInsertReqeust();
                AlihealthKytDrugrescodeReqeust alihealthKytDrugrescodeReqeust = new AlihealthKytDrugrescodeReqeust();
                alihealthKytDrugrescodeReqeust.setPhysic_name(cpmctymc);
                request.setAlihealthKytDrugrescodeReqeust(alihealthKytDrugrescodeReqeust);
                try {
                    BaseResponse<List<ThirdAliDrug>> baseResponse = alihealthUtils.thirdAliDrugInsertAll(request);
                    if(baseResponse.getCode() == 20000){
                        add = baseResponse.getData();
                    }else {
                        log.error("阿里访问失败==="+baseResponse.getMessage());
                    }
                }catch (Exception e){
                    log.error("阿里访问失败==="+e.getMessage());
                }

                thirdAliDrugAddRequest.setList(add);
                this.addThirdAliDrug(thirdAliDrugAddRequest);
                try {
                    Thread.sleep(15000);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        }
    }


    public ThirdAliDrug getThirdAliDrug(String drugCode) {
        ThirdAliDrugRequest thirdAliDrug = new ThirdAliDrugRequest();
        thirdAliDrug.setNameCode(drugCode);
        List<ThirdAliDrug> thirdAliDrugs = this.baseMapper.filterList(thirdAliDrug);
        if (CollUtil.isNotEmpty(thirdAliDrugs)){
            return thirdAliDrugs.get(0);
        }else {
            // TODO: 2025/1/6 前往阿里查找 未找到的话 直接返回  new ThirdAliDrug()

        }
        return new ThirdAliDrug();
    }
}
